package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.SysSdgsat1Case;

/**
 * SDGSAT-1 应用案例数据访问接口
 * 
 * @author ruoyi
 */
public interface SysSdgsat1CaseMapper
{
    /**
     * 查询应用案例列表
     * 
     * @param sysSdgsat1Case 应用案例
     * @return 应用案例集合
     */
    public List<SysSdgsat1Case> selectSysSdgsat1CaseList(SysSdgsat1Case sysSdgsat1Case);

    /**
     * 根据ID查询应用案例
     * 
     * @param id 应用案例ID
     * @return 应用案例
     */
    public SysSdgsat1Case selectSysSdgsat1CaseById(Long id);

    /**
     * 新增应用案例
     * 
     * @param sysSdgsat1Case 应用案例
     * @return 结果
     */
    public int insertSysSdgsat1Case(SysSdgsat1Case sysSdgsat1Case);

    /**
     * 修改应用案例
     * 
     * @param sysSdgsat1Case 应用案例
     * @return 结果
     */
    public int updateSysSdgsat1Case(SysSdgsat1Case sysSdgsat1Case);

    /**
     * 删除应用案例
     * 
     * @param id 应用案例ID
     * @return 结果
     */
    public int deleteSysSdgsat1CaseById(Long id);

    /**
     * 批量删除应用案例
     * 
     * @param ids 应用案例ID数组
     * @return 结果
     */
    public int deleteSysSdgsat1CaseByIds(Long[] ids);
}
